@@ -7,7 +7,10 @@ BEGIN{
 use strict;
 use warnings;
 package App::CSE;
-$App::CSE::VERSION = '0.003';
+{
+  $App::CSE::VERSION = '0.004';
+}
+
 
 use Moose;
 use Class::Load;
@@ -20,6 +23,7 @@ use String::CamelCase;
 use Path::Class::Dir;
 use File::stat;
 use Getopt::Long qw//;
+use XML::LibXML;
 
 use Log::Log4perl qw/:easy/;
 
@@ -129,6 +133,9 @@ has 'index_mtime' => ( is => 'ro' , isa => 'DateTime' , lazy_build => 1);
 has 'index_dirty_file' => ( is => 'ro' , isa => 'Path::Class::File', lazy_build => 1);
 has 'dirty_files' => ( is => 'ro', isa => 'HashRef[Str]', lazy_build => 1);
 
+# File utilities
+has 'xml_parser' => ( is => 'ro' , isa => 'XML::LibXML', lazy_build => 1);
+
 {# Singleton flavour
   my $instance;
   sub BUILD{
@@ -140,6 +147,11 @@ has 'dirty_files' => ( is => 'ro', isa => 'HashRef[Str]', lazy_build => 1);
   }
 }
 
+sub _build_xml_parser{
+  my ($self) = @_;
+  return XML::LibXML->new();
+}
+
 sub _build_colorizer{
   my ($self) = @_;
   return App::CSE::Colorizer->new( { cse => $self } );
